@@ -17,6 +17,9 @@ function(behavior,phaseX,v1,ABxlab,ABylab,ABmain){
   #numx<-sum(!is.na(behavior))+1
   numx=length(x1)+1
   #graphics.off()
+  
+  
+  
   layout(rbind(1,2), heights=c(4,1))
   plot(A,ylim=c(0,max),xlim=c(0,numx),type="o",xlab=ABxlab, ylab=ABylab, main=ABmain,bty='L')
   abline(h=p75,col="blue")
@@ -24,13 +27,14 @@ function(behavior,phaseX,v1,ABxlab,ABylab,ABmain){
   abline(h=medianA,col="orange")
   
   
-  psdu<-c(round(p75,2))
-  pmean<-c(round(medianA,2))
-  psdb<-c(round(p25,2))
+  psdu<-c("75th percentile =",round(p75,2))
+  pmean<-c("median =", round(medianA,2))
+  psdb<-c("25th percentile =", round(p25,2))
   iqr=q[4]-q[2]
   iqrp=c("IQR=",round(iqr,2))
   
-  tprint=c(psdu,pmean,psdb)
-  print(tprint)
- 
+  tprint=c("key:",psdu,pmean,psdb)
+ # print(tprint)
+  writeLines(" ")
+  cat(sprintf(tprint),"\n") 
 }
