@@ -27,13 +27,17 @@ abline(h=meanA,col="orange")
 #par(mar=c(1, 1, 1, 1))
 #plot.new()
 #legend("bottom",inset=c(-.3,-.1,-.3), c("+1sd","mean","-1sd"), col = c("blue","orange", "red"), lwd = 1,ncol=3,bty ="n")
-sd1<-c("SD=",round(sdA,2))
-psdu<-c("+1sd=",round(SDabove,2))
-pmean<-c("mean=",round(meanA,2))
-psdb<-c("-1SD=",round(SDbelow,2))
-print(sd1)
-print(psdu)
-print(pmean)
-print(psdb)
+sd1<-c("  SD =",round(sdA,2))
+psdu<-c("+1sd =",round(SDabove,2))
+pmean<-c("mean =",round(meanA,2))
+psdb<-c("-1SD =",round(SDbelow,2))
+tprint=c(sd1,psdu,pmean,psdb)
+#print(sd1)
+#print(psdu)
+#print(pmean)
+#print(psdb)
+writeLines(" ")
+cat(sprintf(tprint),"\n") 
 
-}
+    
+ }
